SimplePublicKey class

Constructors

SimplePublicKey(Uint8List key)

Properties

hashCode → int
The hash code for this object.
no setterinherited
key ↔ Uint8List
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

address() → String
encodeAminoPubkey() → Uint8List
getPublicKeyAsBase64() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packAny() → Any
pubkeyAddress() → String
rawAddress() → Uint8List
toAmino() → SimplePublicKeyAminoArgs
toData() → SimplePublicKeyDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited