RawKey class

Inheritance
Implementers

Constructors

RawKey()

Properties

hashCode → int
The hash code for this object.
no setterinherited
privateKey ↔ Uint8List?
getter/setter pairinherited
privateKeyExposed ↔ Uint8List?
getter/setter pairinherited
publicKey ↔ SimplePublicKey?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

accAddress() → String
inherited
ecdsaSign(Uint8List payload) → SignatureModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preparePrivateKey(Uint8List? cprivateKey, {bool exposePrivateKey = false}) → void
inherited
sign(Uint8List payload) → Uint8List
Sign the Key
override
toString() → String
A string representation of this object.
inherited
valAddress() → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited